{% extends "admin/base.html" %}
{% load i18n %}

{% block content_title %}
    {% trans "Password changed" %}
{% endblock %}

{% block content %}
<div class="max-w-lg">
    <div class="bg-white dark:bg-gray-800 rounded-lg shadow-sm border border-gray-200 dark:border-gray-700">
        
        <div class="p-8 text-center">
            <!-- Success Icon -->
            <div class="w-16 h-16 bg-green-100 dark:bg-green-900/30 rounded-full flex items-center justify-center mx-auto mb-6">
                <svg class="w-8 h-8 text-green-600 dark:text-green-400" fill="none" stroke="currentColor" viewBox="0 0 24 24">
                    <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M5 13l4 4L19 7"/>
                </svg>
            </div>
            
            <h2 class="text-xl font-semibold text-gray-900 dark:text-white mb-2">
                {% trans "Password changed successfully!" %}
            </h2>
            
            <p class="text-gray-600 dark:text-gray-400 mb-8">
                {% trans "Your password has been changed. You can continue using the admin site." %}
            </p>
            
            <a href="{% url 'admin:index' %}" class="inline-flex items-center px-6 py-2.5 bg-blue-600 hover:bg-blue-700 text-white rounded-lg font-medium transition-colors">
                <svg class="w-5 h-5 mr-2" fill="none" stroke="currentColor" viewBox="0 0 24 24">
                    <path stroke-linecap="round" stroke-linejoin="round" stroke-width="2" d="M3 12l2-2m0 0l7-7 7 7M5 10v10a1 1 0 001 1h3m10-11l2 2m-2-2v10a1 1 0 01-1 1h-3m-6 0a1 1 0 001-1v-4a1 1 0 011-1h2a1 1 0 011 1v4a1 1 0 001 1m-6 0h6"/>
                </svg>
                {% trans "Back to Dashboard" %}
            </a>
        </div>
    </div>
</div>
{% endblock %}